@@ -33,17 +33,14 @@ alpha    = "abcdefghijklmnopqrstuvwxyz"
 nonalpha = {"&" : "ampersand",
             "*" : "asterix",
             "@" : "at",
-            "|" : "bar",
             "^" : "caret",
             ":" : "colon",
             "$" : "dollar",
             "=" : "equals",
             "!" : "exclamation",
             "/" : "forwardslash",
-            ">" : "greaterthan",
             "#" : "hash",
             "-" : "hyphen",
-            "<" : "lessthan",
             "%" : "percent",
             "+" : "plus",
             "?" : "question",
